/*
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for
 * license information.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */

'use strict';

const models = require('./index');

/**
 * @class
 * Initializes a new instance of the EventHubModel class.
 * @constructor
 * Description of the Event Hub resource.
 *
 * @member {date} [createdAt] Exact time the Event Hub was created.
 *
 * @member {number} [messageRetentionInDays] Number of days to retain the
 * events for this Event Hub.
 *
 * @member {number} [partitionCount] Number of partitions created for the Event
 * Hub.
 *
 * @member {array} [partitionIds] Current number of shards on the Event Hub.
 *
 * @member {string} [status] Enumerates the possible values for the status of
 * the Event Hub. Possible values include: 'Active', 'Disabled', 'Restoring',
 * 'SendDisabled', 'ReceiveDisabled', 'Creating', 'Deleting', 'Renaming',
 * 'Unknown'
 *
 * @member {date} [updatedAt] The exact time the message was updated.
 *
 */
class EventHubModel extends models['Resource'] {
  constructor() {
    super();
  }

  /**
   * Defines the metadata of EventHubModel
   *
   * @returns {object} metadata of EventHubModel
   *
   */
  mapper() {
    return {
      required: false,
      serializedName: 'EventHub',
      type: {
        name: 'Composite',
        className: 'EventHubModel',
        modelProperties: {
          id: {
            required: false,
            readOnly: true,
            serializedName: 'id',
            type: {
              name: 'String'
            }
          },
          name: {
            required: false,
            readOnly: true,
            serializedName: 'name',
            type: {
              name: 'String'
            }
          },
          type: {
            required: false,
            readOnly: true,
            serializedName: 'type',
            type: {
              name: 'String'
            }
          },
          createdAt: {
            required: false,
            readOnly: true,
            serializedName: 'properties.createdAt',
            type: {
              name: 'DateTime'
            }
          },
          messageRetentionInDays: {
            required: false,
            serializedName: 'properties.messageRetentionInDays',
            type: {
              name: 'Number'
            }
          },
          partitionCount: {
            required: false,
            serializedName: 'properties.partitionCount',
            type: {
              name: 'Number'
            }
          },
          partitionIds: {
            required: false,
            readOnly: true,
            serializedName: 'properties.partitionIds',
            type: {
              name: 'Sequence',
              element: {
                  required: false,
                  serializedName: 'StringElementType',
                  type: {
                    name: 'String'
                  }
              }
            }
          },
          status: {
            required: false,
            readOnly: true,
            serializedName: 'properties.status',
            type: {
              name: 'Enum',
              allowedValues: [ 'Active', 'Disabled', 'Restoring', 'SendDisabled', 'ReceiveDisabled', 'Creating', 'Deleting', 'Renaming', 'Unknown' ]
            }
          },
          updatedAt: {
            required: false,
            readOnly: true,
            serializedName: 'properties.updatedAt',
            type: {
              name: 'DateTime'
            }
          }
        }
      }
    };
  }
}

module.exports = EventHubModel;
