/*
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for
 * license information.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */

import { BaseResource } from 'ms-rest-azure';
import { CloudError } from 'ms-rest-azure';

export { BaseResource } from 'ms-rest-azure';
export { CloudError } from 'ms-rest-azure';


/**
 * @class
 * Initializes a new instance of the OperationDisplay class.
 * @constructor
 * The object that represents the operation.
 *
 * @member {string} [provider] Service provider: Microsoft.EventHub
 *
 * @member {string} [resource] Resource on which the operation is performed:
 * Invoice, etc.
 *
 * @member {string} [operation] Operation type: Read, write, delete, etc.
 *
 */
export interface OperationDisplay {
  readonly provider?: string;
  readonly resource?: string;
  readonly operation?: string;
}

/**
 * @class
 * Initializes a new instance of the Operation class.
 * @constructor
 * A EventHub REST API operation
 *
 * @member {string} [name] Operation name: {provider}/{resource}/{operation}
 *
 * @member {object} [display] The object that represents the operation.
 *
 * @member {string} [display.provider] Service provider: Microsoft.EventHub
 *
 * @member {string} [display.resource] Resource on which the operation is
 * performed: Invoice, etc.
 *
 * @member {string} [display.operation] Operation type: Read, write, delete,
 * etc.
 *
 */
export interface Operation {
  readonly name?: string;
  display?: OperationDisplay;
}

/**
 * @class
 * Initializes a new instance of the OperationListResult class.
 * @constructor
 * Result of the request to list EventHub operations. It contains a list of
 * operations and a URL link to get the next set of results.
 *
 * @member {array} [value] List of EventHub operations supported by the
 * Microsoft.EventHub resource provider.
 *
 * @member {string} [nextLink] URL to get the next set of operation list
 * results if there are any.
 *
 */
export interface OperationListResult {
  readonly value?: Operation[];
  readonly nextLink?: string;
}

/**
 * @class
 * Initializes a new instance of the TrackedResource class.
 * @constructor
 * Definition of Resource
 *
 * @member {string} location Resource location
 *
 * @member {object} [tags] Resource tags
 *
 */
export interface TrackedResource extends BaseResource {
  location: string;
  tags?: { [propertyName: string]: string };
}

/**
 * @class
 * Initializes a new instance of the Resource class.
 * @constructor
 * The Resource definition
 *
 * @member {string} [id] Resource Id
 *
 * @member {string} [name] Resource name
 *
 * @member {string} [type] Resource type
 *
 */
export interface Resource extends BaseResource {
  readonly id?: string;
  readonly name?: string;
  readonly type?: string;
}

/**
 * @class
 * Initializes a new instance of the Sku class.
 * @constructor
 * SKU of the namespace.
 *
 * @member {string} [name] Name of this SKU. Possible values include: 'Basic',
 * 'Standard'
 *
 * @member {string} tier The billing tier of this particular SKU. Possible
 * values include: 'Basic', 'Standard', 'Premium'
 *
 * @member {number} [capacity] The EventHubs throughput units.
 *
 */
export interface Sku {
  name?: string;
  tier: string;
  capacity?: number;
}

/**
 * @class
 * Initializes a new instance of the Namespace class.
 * @constructor
 * Description of a namespace resource.
 *
 * @member {object} [sku]
 *
 * @member {string} [sku.name] Name of this SKU. Possible values include:
 * 'Basic', 'Standard'
 *
 * @member {string} [sku.tier] The billing tier of this particular SKU.
 * Possible values include: 'Basic', 'Standard', 'Premium'
 *
 * @member {number} [sku.capacity] The EventHubs throughput units.
 *
 * @member {string} [provisioningState] Provisioning state of the namespace.
 *
 * @member {date} [createdAt] The time the namespace was created.
 *
 * @member {date} [updatedAt] The time the namespace was updated.
 *
 * @member {string} [serviceBusEndpoint] Endpoint you can use to perform
 * Service Bus operations.
 *
 */
export interface Namespace extends TrackedResource {
  sku?: Sku;
  readonly provisioningState?: string;
  readonly createdAt?: Date;
  readonly updatedAt?: Date;
  readonly serviceBusEndpoint?: string;
}

/**
 * @class
 * Initializes a new instance of the NamespaceListResult class.
 * @constructor
 * The response of the List Namespace operation.
 *
 * @member {array} [value] Result of the List Namespace operation.
 *
 * @member {string} [nextLink] Link to the next set of results. Not empty if
 * Value contains incomplete list of namespaces.
 *
 */
export interface NamespaceListResult {
  value?: Namespace[];
  nextLink?: string;
}

/**
 * @class
 * Initializes a new instance of the SharedAccessAuthorizationRule class.
 * @constructor
 * Description of a namespace authorization rule.
 *
 * @member {array} rights The rights associated with the rule.
 *
 */
export interface SharedAccessAuthorizationRule extends Resource {
  rights: string[];
}

/**
 * @class
 * Initializes a new instance of the SharedAccessAuthorizationRuleListResult class.
 * @constructor
 * The response from the List Namespace operation.
 *
 * @member {array} [value] Result of the List Authorization Rules operation.
 *
 * @member {string} [nextLink] Link to the next set of results. Not empty if
 * Value contains an incomplete list of Authorization Rules
 *
 */
export interface SharedAccessAuthorizationRuleListResult {
  value?: SharedAccessAuthorizationRule[];
  nextLink?: string;
}

/**
 * @class
 * Initializes a new instance of the ResourceListKeys class.
 * @constructor
 * Namespace/EventHub Connection String
 *
 * @member {string} [primaryConnectionString] Primary connection string of the
 * created namespace authorization rule.
 *
 * @member {string} [secondaryConnectionString] Secondary connection string of
 * the created namespace authorization rule.
 *
 * @member {string} [primaryKey] A base64-encoded 256-bit primary key for
 * signing and validating the SAS token.
 *
 * @member {string} [secondaryKey] A base64-encoded 256-bit secondary key for
 * signing and validating the SAS token.
 *
 * @member {string} [keyName] A string that describes the authorization rule.
 *
 */
export interface ResourceListKeys {
  readonly primaryConnectionString?: string;
  readonly secondaryConnectionString?: string;
  readonly primaryKey?: string;
  readonly secondaryKey?: string;
  readonly keyName?: string;
}

/**
 * @class
 * Initializes a new instance of the RegenerateKeysParameters class.
 * @constructor
 * Parameters supplied to the Regenerate Authorization Rule operation.
 *
 * @member {string} [policykey] Key that needs to be regenerated. Possible
 * values include: 'PrimaryKey', 'SecondaryKey'
 *
 */
export interface RegenerateKeysParameters {
  policykey?: string;
}

/**
 * @class
 * Initializes a new instance of the EventHubModel class.
 * @constructor
 * Description of the Event Hub resource.
 *
 * @member {date} [createdAt] Exact time the Event Hub was created.
 *
 * @member {number} [messageRetentionInDays] Number of days to retain the
 * events for this Event Hub.
 *
 * @member {number} [partitionCount] Number of partitions created for the Event
 * Hub.
 *
 * @member {array} [partitionIds] Current number of shards on the Event Hub.
 *
 * @member {string} [status] Enumerates the possible values for the status of
 * the Event Hub. Possible values include: 'Active', 'Disabled', 'Restoring',
 * 'SendDisabled', 'ReceiveDisabled', 'Creating', 'Deleting', 'Renaming',
 * 'Unknown'
 *
 * @member {date} [updatedAt] The exact time the message was updated.
 *
 */
export interface EventHubModel extends Resource {
  readonly createdAt?: Date;
  messageRetentionInDays?: number;
  partitionCount?: number;
  readonly partitionIds?: string[];
  readonly status?: string;
  readonly updatedAt?: Date;
}

/**
 * @class
 * Initializes a new instance of the EventHubListResult class.
 * @constructor
 * The response of the List Event Hubs operation.
 *
 * @member {array} [value] Result of the List Event Hubs operation.
 *
 * @member {string} [nextLink] Link to the next set of results. Not empty if
 * Value contains incomplete list of Event Hubs.
 *
 */
export interface EventHubListResult {
  value?: EventHubModel[];
  nextLink?: string;
}

/**
 * @class
 * Initializes a new instance of the ConsumerGroup class.
 * @constructor
 * Description of the consumer group resource.
 *
 * @member {date} [createdAt] Exact time the message was created.
 *
 * @member {string} [eventHubPath] The path of the Event Hub.
 *
 * @member {date} [updatedAt] The exact time the message was updated.
 *
 * @member {string} [userMetadata] Usermetadata is a placeholder to store
 * user-defined string data with maximum length 1024. e.g. it can be used to
 * store descriptive data, such as list of teams and their contact information
 * also user-defined configuration settings can be stored.
 *
 */
export interface ConsumerGroup extends Resource {
  readonly createdAt?: Date;
  readonly eventHubPath?: string;
  readonly updatedAt?: Date;
  userMetadata?: string;
}

/**
 * @class
 * Initializes a new instance of the ConsumerGroupListResult class.
 * @constructor
 * The response to the List Consumer Group operation.
 *
 * @member {array} [value] Result of the List Consumer Group operation.
 *
 * @member {string} [nextLink] Link to the next set of results. Not empty if
 * Value contains incomplete list of Consumer Group
 *
 */
export interface ConsumerGroupListResult {
  value?: ConsumerGroup[];
  nextLink?: string;
}

/**
 * @class
 * Initializes a new instance of the CheckNameAvailability class.
 * @constructor
 * Description of a Check Name availability request properties.
 *
 * @member {string} name The Name to check the namespce name availability
 *
 */
export interface CheckNameAvailability {
  name: string;
}

/**
 * @class
 * Initializes a new instance of the CheckNameAvailabilityResult class.
 * @constructor
 * Description of a Check Name availability request properties.
 *
 * @member {boolean} [nameAvailable] Value indicating namespace is
 * availability, true if the namespace is available; otherwise, false.
 *
 * @member {string} [reason] The reason for unavailability of a namespace.
 * Possible values include: 'None', 'InvalidName', 'SubscriptionIsDisabled',
 * 'NameInUse', 'NameInLockdown', 'TooManyNamespaceInCurrentSubscription'
 *
 * @member {string} [message] The detailed info regarding the reason associated
 * with the namespace.
 *
 */
export interface CheckNameAvailabilityResult {
  nameAvailable?: boolean;
  reason?: string;
  readonly message?: string;
}

/**
 * @class
 * Initializes a new instance of the NamespaceUpdateParameter class.
 * @constructor
 * Parameters supplied to the Patch Namespace operation.
 *
 * @member {object} [tags] Resource tags
 *
 * @member {object} [sku] The sku of the created namespace
 *
 * @member {string} [sku.name] Name of this SKU. Possible values include:
 * 'Basic', 'Standard'
 *
 * @member {string} [sku.tier] The billing tier of this particular SKU.
 * Possible values include: 'Basic', 'Standard', 'Premium'
 *
 * @member {number} [sku.capacity] The EventHubs throughput units.
 *
 */
export interface NamespaceUpdateParameter {
  tags?: { [propertyName: string]: string };
  sku?: Sku;
}

/**
 * @class
 * Initializes a new instance of the ErrorResponse class.
 * @constructor
 * Error reponse indicates EventHub service is not able to process the incoming
 * request. The reason is provided in the error message.
 *
 * @member {string} [code] Error code.
 *
 * @member {string} [message] Error message indicating why the operation
 * failed.
 *
 */
export interface ErrorResponse {
  code?: string;
  message?: string;
}

/**
 * @class
 * Initializes a new instance of the OperationListResult class.
 * @constructor
 * Result of the request to list EventHub operations. It contains a list of
 * operations and a URL link to get the next set of results.
 *
 * @member {array} [value] List of EventHub operations supported by the
 * Microsoft.EventHub resource provider.
 *
 * @member {string} [nextLink] URL to get the next set of operation list
 * results if there are any.
 *
 */
export interface OperationListResult {
  readonly value?: Operation[];
  readonly nextLink?: string;
}

/**
 * @class
 * Initializes a new instance of the NamespaceListResult class.
 * @constructor
 * The response of the List Namespace operation.
 *
 * @member {array} [value] Result of the List Namespace operation.
 *
 * @member {string} [nextLink] Link to the next set of results. Not empty if
 * Value contains incomplete list of namespaces.
 *
 */
export interface NamespaceListResult {
  value?: Namespace[];
  nextLink?: string;
}

/**
 * @class
 * Initializes a new instance of the SharedAccessAuthorizationRuleListResult class.
 * @constructor
 * The response from the List Namespace operation.
 *
 * @member {array} [value] Result of the List Authorization Rules operation.
 *
 * @member {string} [nextLink] Link to the next set of results. Not empty if
 * Value contains an incomplete list of Authorization Rules
 *
 */
export interface SharedAccessAuthorizationRuleListResult {
  value?: SharedAccessAuthorizationRule[];
  nextLink?: string;
}

/**
 * @class
 * Initializes a new instance of the EventHubListResult class.
 * @constructor
 * The response of the List Event Hubs operation.
 *
 * @member {array} [value] Result of the List Event Hubs operation.
 *
 * @member {string} [nextLink] Link to the next set of results. Not empty if
 * Value contains incomplete list of Event Hubs.
 *
 */
export interface EventHubListResult {
  value?: EventHubModel[];
  nextLink?: string;
}

/**
 * @class
 * Initializes a new instance of the ConsumerGroupListResult class.
 * @constructor
 * The response to the List Consumer Group operation.
 *
 * @member {array} [value] Result of the List Consumer Group operation.
 *
 * @member {string} [nextLink] Link to the next set of results. Not empty if
 * Value contains incomplete list of Consumer Group
 *
 */
export interface ConsumerGroupListResult {
  value?: ConsumerGroup[];
  nextLink?: string;
}


/**
 * @class
 * Initializes a new instance of the OperationListResult class.
 * @constructor
 * Result of the request to list EventHub operations. It contains a list of
 * operations and a URL link to get the next set of results.
 *
 * @member {string} [nextLink] URL to get the next set of operation list
 * results if there are any.
 *
 */
export interface OperationListResult extends Array<Operation> {
  readonly nextLink?: string;
}

/**
 * @class
 * Initializes a new instance of the NamespaceListResult class.
 * @constructor
 * The response of the List Namespace operation.
 *
 * @member {string} [nextLink] Link to the next set of results. Not empty if
 * Value contains incomplete list of namespaces.
 *
 */
export interface NamespaceListResult extends Array<Namespace> {
  nextLink?: string;
}

/**
 * @class
 * Initializes a new instance of the SharedAccessAuthorizationRuleListResult class.
 * @constructor
 * The response from the List Namespace operation.
 *
 * @member {string} [nextLink] Link to the next set of results. Not empty if
 * Value contains an incomplete list of Authorization Rules
 *
 */
export interface SharedAccessAuthorizationRuleListResult extends Array<SharedAccessAuthorizationRule> {
  nextLink?: string;
}

/**
 * @class
 * Initializes a new instance of the EventHubListResult class.
 * @constructor
 * The response of the List Event Hubs operation.
 *
 * @member {string} [nextLink] Link to the next set of results. Not empty if
 * Value contains incomplete list of Event Hubs.
 *
 */
export interface EventHubListResult extends Array<EventHubModel> {
  nextLink?: string;
}

/**
 * @class
 * Initializes a new instance of the ConsumerGroupListResult class.
 * @constructor
 * The response to the List Consumer Group operation.
 *
 * @member {string} [nextLink] Link to the next set of results. Not empty if
 * Value contains incomplete list of Consumer Group
 *
 */
export interface ConsumerGroupListResult extends Array<ConsumerGroup> {
  nextLink?: string;
}
